A library for working with light sheet imaging data of developing embryos, e.g. _Tribolium castaneum_.

![](https://github.com/haesleinhuepf/beetlesafari/raw/master/images/beetlesafari.gif)
[Image data source: Daniela Vorkel, Myers lab, MPI CBG]

# Installation
```
conda install -c conda-forge pyopencl
pip install beetlesafari
```
